#define _requires_exceptions libblas.so.3\\|jaxp_parser_impl\\|

# baserelease defines which build revision of this version we're building.
# The magical name baserelease is matched by the rpmdev-bumpspec tool, which
# you should use.
%global baserelease 1

# On a released (stable or beta) version set it to 1
%define is_release 1
# On a stable version set it to 1
%define is_stable 0

# On a pre-release packages set this to the selected name
%define prerelease_name beta-1

# pkg_release is what we'll fill in for the rpm Release: field
%if %{is_release}
    %if %{is_stable}
        # stable release
        %define pkg_release %{baserelease}%{?dist}
    %else
        # alpha or beta release
        %define escaped_prerelease_name %(echo %{prerelease_name} |tr -cd [:alnum:])
        %define pkg_release 0.%{baserelease}.%{escaped_prerelease_name}%{?dist}
    %endif
%else
    # nightly build
    %define pkg_release 0.%{baserelease}.%{prerelease_date}snap%{?dist}
%endif


Summary:	A high-level language for numerical computations
Name:		scilab
Version:	5.5.0
Release:	%mkrel 0.beta1.4
License:	CeCILL
Group:		Sciences/Mathematics
URL:		http://www.scilab.org/
%if %{is_release}
    %if %{is_stable}
        # stable release
Source0:        http://www.scilab.org/download/%{version}/scilab-%{version}-src.tar.gz
    %else
        # alpha or beta release
Source0:        http://www.scilab.org/download/%{version}-%{prerelease_name}/scilab-%{version}-%{prerelease_name}-src.tar.gz
    %endif
%else
    # nightly build
Source0:        http://downloadarea.scilab.org/download/%(date -d%{prerelease_date} +%%Y-%%m-%%d)/scilab-master-%{prerelease_timestamp}-src.tar.gz
%endif

Source1:	scilabsymbols.ttf
Source20:	scilab.el

# Bug 767102 - help() should suggest scilab-doc
Patch1:         %{name}-0001-Use-pkcon-to-install-doc-package.patch
# Bug 64307 - Use dynamic stack on 32-bit to avoid miscompilation
# http://bugzilla.scilab.org/show_bug.cgi?id=12625
Patch2:         %{name}-0002-always-use-dynamic-stack.patch
# Track heap space error on arm builders
Patch3:         %{name}-0003-report-issues-on-arm-build.patch

Patch6:		%{name}-5.3.3-modelica.patch
# mga#6055
Patch7:		%{name}-5.5.0-beta-1-desktop-files.patch
BuildRequires:	automake
BuildRequires:	gettext-devel
BuildRequires:	tcl-devel >= 8.5
BuildRequires:	tk-devel >= 8.5
BuildRequires:	xaw-devel
BuildRequires:	emacs-nox
BuildRequires:	gcc-gfortran
BuildRequires:  quadmath-devel
BuildRequires:	GL-devel
BuildRequires:	libgomp-devel
BuildRequires:	ocaml
BuildRequires:	imagemagick
BuildRequires:	sablotron
BuildRequires:	arpack-devel
BuildRequires:	fftw3-devel
BuildRequires:	java-rpmbuild
BuildRequires:	ant
BuildRequires:	checkstyle
BuildRequires:	flexdock
BuildRequires:	jgoodies-looks
BuildRequires:	suitesparse-devel
# jhall == javahelp2
BuildRequires:	javahelp2
#BuildRequires:	gluegen2
BuildRequires:	jrosetta
BuildRequires:	matio-devel
BuildRequires:	swig
BuildRequires:	ncurses-devel
BuildRequires:	pcreposix-devel
BuildRequires:	giws
BuildRequires:	docbook-style-xsl
BuildRequires:	batik
BuildRequires:	saxon
BuildRequires:	fop
BuildRequires:	jeuclid-core
BuildRequires:	python-libxml2
BuildRequires:	qdox
BuildRequires:	xml-commons-jaxp-1.3-apis >= 1.3.04-3.0.4
BuildRequires:	jgraphx
BuildRequires:	jlatexmath >= 1.0.2
BuildRequires:	antlr
BuildRequires:	jakarta-commons-beanutils
BuildRequires:	chrpath
#BuildRequires:	hdf-java
BuildRequires:	hdf5-devel
BuildRequires:	xmlgraphics-commons
BuildRequires:	termcap-devel
BuildRequires:	junit
BuildRequires:  scirenderer >= 1.1.0
BuildRequires:  curl-devel

Requires:	tcl >= 8.5
Requires:	tk >= 8.5
Requires:	ocaml
Requires:	gcc-gfortran
Requires:	flexdock
Requires:	jgoodies-looks
#Requires:	jogl2
Requires:	jrosetta
#Requires:	gluegen2
Requires:	javahelp2
Requires:	fop
Requires:	saxon
Requires:	batik
Requires:	jeuclid-core
Requires:	java > 1.5
Requires:	xerces-j2
Requires:	arpack
Requires:	fftw
Requires:	libmatio
Requires:	suitesparse
Requires:	docbook-style-xsl
Requires:	swig
Requires:	giws
Requires:	sablotron
Requires:	jgraphx
Requires:	jlatexmath
#Requires:	hdf-java
Requires:  scirenderer

%description
Scilab is a high-level language, primarily intended for numerical
computations.  Scilab includes a number of toolboxes and on-line
documentation.

%package devel
Summary:	Development files for %{name}
Group:		Development/Other

%description devel
Development files and headers for %{name}.

%prep
%if %{is_release}
    %if %{is_stable}
%setup -q
    %else
%setup -q -n %{name}-%{version}-%{prerelease_name}
    %endif
%else
%setup -q -n %{name}-master-%{prerelease_timestamp}
%endif

%patch1 -p1 -b .pkgcon
%patch2 -p1 -b .stack
%patch3 -p1 -b .arm
%patch7 -p1

# Update saxon dependency
# http://bugzilla.scilab.org/show_bug.cgi?id=8479
sed -i "s/com.icl.saxon.Loader/net.sf.saxon.Version/g" m4/docbook.m4 configure
rm modules/helptools/src/java/org/scilab/modules/helptools/BuildDocObject.java

%build
%define _disable_ld_no_undefined 1
%define _disable_ld_as_needed 1
%define Werror_cflags %nil
export JAVA_HOME=%{java_home}
export CXXFLAGS=" $(echo %{optflags}) -fpermissive"

# patched configure.ac
#autoreconf -ifs

%configure2_5x \
	--with-tk-library=%{_libdir} \
	--with-tcl-library=%{_libdir} \
	--with-blas-library=%{_libdir} \
	--with-lapack-library=%{_libdir} \
	--with-jdk=%{java_home} \
	--disable-rpath \
	--without-umfpack \
	--with-pcre=%{_bindir} \
	--enable-shared \
	--disable-static \
	--with-gfortran \
	--with-gcc \
	--with-fftw \
	--enable-build-localization \
	--enable-build-help \
	--with-docbook="/usr/share/sgml/docbook/xsl-stylesheets-1.75.2" \
	--enable-build-swig \
	--disable-build-giws \
	--with-install-help-xml \
	--with-gui \
	--enable-relocatable \
	--disable-static-system-lib

#	--with-umfpack-library="-lumfpack -lSuiteSparse" \

%make all
%make doc

cp -af %{SOURCE20} .
for i in emacs; do
	$i -batch -q -no-site-file -f batch-byte-compile %{name}.el
	mv %{name}.elc $i-%{name}.elc
done

%install
rm -rf %{buildroot}
%makeinstall_std

# (tpg) delete empty dirs
find %{buildroot}%{_datadir}/%{name} -type d -empty -delete

# (tpg) get rid of this
rm %{buildroot}%{_datadir}/%{name}/README_Windows.txt
find %{buildroot} -name '*.la' | xargs rm

# (X)emacs
for i in emacs; do
	mkdir -p %{buildroot}%{_datadir}/$i/site-lisp/
	mkdir -p %{buildroot}%{_datadir}/emacs/site-lisp/
	install -m644 $i-%{name}.elc %{buildroot}%{_datadir}/$i/site-lisp/
	[[ $i = emacs ]] && install -m644 %{name}.el %{buildroot}%{_datadir}/emacs/site-lisp/
done

mkdir -p %{buildroot}/%{_sysconfdir}/emacs/site-start.d
install -m644 %{SOURCE20} %{buildroot}/%{_sysconfdir}/emacs/site-start.d/%{name}.el

# (tpg) correct path for *.so java libraries
sed -i -e 's#/usr/lib/jni/#%{_libdir}#g' %{buildroot}%{_datadir}/%{name}/etc/librarypath.xml

# (tpg) fonts
mkdir -p %{buildroot}%{_datadir}/%{name}/thirdparty/fonts
install -m644 %{SOURCE1} %{buildroot}%{_datadir}/%{name}/thirdparty/fonts/

# (tpg) nuke rpath
for file in %{buildroot}%{_bindir}/{intersci,scilab-bin,scilab-cli-bin}; do \
    chrpath -d $file; \
done

# (tpg) get rid of files with licenses
rm %{buildroot}%{_datadir}/%{name}/modules/*/license.txt
rm %{buildroot}%{_datadir}/%{name}/contrib/toolbox_skeleton/license.txt 
rm %{buildroot}%{_datadir}/%{name}/modules/tclsci/tcl/sciGUI/license.txt
rm %{buildroot}%{_datadir}/%{name}/modules/umfpack/TAUCS_license.txt 
rm %{buildroot}%{_datadir}/%{name}/modules/umfpack/UMFPACK_license.txt

# Use the new ld.so.conf.d
mkdir -p %buildroot/%_sysconfdir/ld.so.conf.d
pushd %buildroot/%_sysconfdir/ld.so.conf.d
echo "%{_libdir}/%name" > %name.conf
popd


%find_lang %{name}

%clean
rm -rf %{buildroot}

%files -f %{name}.lang
%defattr(-,root,root)
%doc ACKNOWLEDGEMENTS CHANGES_5.3.X license.txt RELEASE_NOTES_5.3.X README_Unix
%{_sysconfdir}/ld.so.conf.d/*
%{_bindir}/*
%{_libdir}/scilab
%{_iconsdir}/hicolor/*/apps/*.png
%{_iconsdir}/hicolor/*/mimetypes/application-x-%{name}-*.png
%config(noreplace) /etc/emacs/site-start.d/%{name}.el
%{_datadir}/*/site-lisp/*el*
%{_datadir}/applications/*.desktop
%{_datadir}/mime/packages/*.xml
%{_datadir}/%{name}

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}
%{_libdir}/pkgconfig/*.pc


%changelog
* Wed Feb 19 2014 alexl <alexl> 5.5.0-0.beta1.4.mga4
+ Revision: 594820
- fix categories in desktop files
- add russian translations in desktop files

* Mon Dec 02 2013 grenoya <grenoya> 5.5.0-0.beta1.3.mga4
+ Revision: 554718
- fix require on suitesparse

* Sun Dec 01 2013 grenoya <grenoya> 5.5.0-0.beta1.2.mga4
+ Revision: 554577
- disable giws rebuild
- new version 5.4.1

  + umeabot <umeabot>
    - Mageia 4 Mass Rebuild

  + dmorgan <dmorgan>
    - Update to 5.5.0 beta1

* Sat Aug 03 2013 grenoya <grenoya> 5.4.0-2.mga4
+ Revision: 462993
- revert new version
- rebuild for new hdf5

  + fwang <fwang>
    - new version 5.4.1

* Wed Jan 16 2013 dmorgan <dmorgan> 5.4.0-2.mga3
+ Revision: 388778
- Appy patches
  Remove sed for jgraphx check
- Rebuild against new jhdf5
- Rebuild against new struts12

  + grenoya <grenoya>
    - finish spec file adaptation to new version
    - new version 5.4.0 (empty build)

  + umeabot <umeabot>
    - Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

  + fwang <fwang>
    - rebuild for new libamd and libumfpack

* Sun Dec 11 2011 eatdirt <eatdirt> 5.3.3-2.mga2
+ Revision: 180487
- Rebuilt for fftw-3.3

* Mon Oct 31 2011 grenoya <grenoya> 5.3.3-1.mga2
+ Revision: 160682
- add new patch(#8) due to nex version of fop which drop thingd already included in xmlgraphics-commons
- remove patch #5 not needed with actual java stack
- add patch #7 (hdf5 version restriction for xcos seems to be false)
- remove BuildConflict scilab (did not apply in mageia)
- convert BuildConflicts for junit and termcap-devel into BuildRequires (no harm done during build and no esplainations of why it was buildconflicts)

  + fwang <fwang>
    - drop .la files

  + tv <tv>
    - new release

* Tue Apr 26 2011 wally <wally> 5.3.0-2.mga1
+ Revision: 91824
- fix desktop file name (mga#954)
- drop buildroot definition

* Thu Apr 07 2011 grenoya <grenoya> 5.3.0-1.mga1
+ Revision: 81681
- clean old Mdv syntax
- add BuildConflicts with xmlgraphics-fop
- imported package scilab


* Thu Jan 27 2011 Paulo Andrade <pcpa@mandriva.com.br> 5.3.0-1mdv2011.0
+ Revision: 633296
- Enable scicos
- Update to scilab 5.3.0

* Sat Jul 31 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 5.2.2-3mdv2011.0
+ Revision: 564052
- Patch18: set java library path

* Tue May 18 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 5.2.2-2mdv2010.1
+ Revision: 545244
- Patch16: fix LD_PRELOAD paths
- Patch17: add more paths into the librarypath.xml file
- add requires on hdf-java for mdv > 2010.0

* Mon May 17 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 5.2.2-1mdv2010.1
+ Revision: 545046
- Patch15: incerase java heap memory size
- enable build documentation, source 2 and 3 are not needed now (mdvbz #57481)
- nuke rpath from binaries
- get rid of empty directories and files with licenses
- fix jgraphx version compare logic in cofigure script
- add buildconflicts on junit
- use enable-relocatable
- Patch14: fix build against java-hdf
- add buildrequires on hdf5-devel
- enable hdf5 support for mdv release greater than 2010.0 (mdvbz #57308)
- update to new version 5.2.2
- diable patches 5 and 6 (not needed anymore)

* Sun Jan 31 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 5.2.0-1mdv2010.1
+ Revision: 498894
- add buildconflicts on termcap-devel
- add buildrequires on jakarta-commons-beanutils and antlr
- add requires on jgraphx and jlatexmath
- rediff patches 5 and 6
- disable patches 7 and 10 (probably not needed anymore)
- nuke rpath
- update to new version 5.2.0

* Sun Sep 27 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 5.1.1-2mdv2010.0
+ Revision: 449910
- final rebuild

* Sun Jun 21 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 5.1.1-1mdv2010.0
+ Revision: 387632
- add buildrequires on xml-commons-jaxp-1.3-apis
- use mandriva specific name of xml-commons-jaxp-1.3-apis-ext jar file
- remove GiwsException files, workaround
- update to new version 5.1.1

* Wed Mar 04 2009 Paulo Andrade <pcpa@mandriva.com.br> 5.1-3mdv2009.1
+ Revision: 348617
- Update patch based on upstream correction to the libxml2
  problem. Only difference in this patch is that it doesn't call
  xmlCleanupParser() in modules/core/src/c/TerminateCore.c
  (it is already exiting), and also removes the call in
  modules/localization/src/c/loadhashtableslocalization.c

* Tue Mar 03 2009 Paulo Andrade <pcpa@mandriva.com.br> 5.1-2mdv2009.1
+ Revision: 348171
- Don't call xmlCleanupParser() if not done using libxml. It appears the
  call was done to "pair" with the call to xmlParseFile(filename_xml_conf),
  what is wrong, as xmlCleanupParser() should be called (only once?) when
  it is known that libxml functions will no longer be called again.
  See also: http://mail.gnome.org/archives/xml/2003-January/msg00155.html

* Wed Feb 18 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 5.1-1mdv2009.1
+ Revision: 342618
- disable patches 8,9 and 11-13, further investigate which one need to be drop
- Patch10: rediff
- remove few hacks, not needed
- update to new version 5.1

* Wed Feb 11 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 5.0.3-12mdv2009.1
+ Revision: 339352
- Patch10: add one more fix against tcl-8.6

* Tue Dec 16 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 5.0.3-11mdv2009.1
+ Revision: 314959
- disable -Werror=format-security cflag for now, need time and effort to fix all issues caused by this
- Patch13: correct LD_LIBRARY_PATH

* Sun Dec 14 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 5.0.3-10mdv2009.1
+ Revision: 314342
- Patch12: link against libfftw3.so.3
- add fonts, and help jar files
- correct patch for loading java *.so libraries
- install xml help files
- add requires on libmatio, libumfpack, swig, giws, sablotron and docbook-style-xsl

* Sat Dec 13 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 5.0.3-9mdv2009.1
+ Revision: 313929
- add requires on fop, saxon, batik and jeuclid-core

* Sat Dec 13 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 5.0.3-8mdv2009.1
+ Revision: 313862
- add requires on fftw
- Patch11: add path to mdv jre
- get rid of duplicated shlashes for java modules path

* Sat Dec 06 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 5.0.3-7mdv2009.1
+ Revision: 311170
- do not directly require libblas.so.3, as there are two libraries which provides this
- somehow requires on xerces-j2 was removed

* Fri Dec 05 2008 Adam Williamson <awilliamson@mandriva.org> 5.0.3-6mdv2009.1
+ Revision: 310838
- add tcl86.patch: kludge build for tcl 8.6

  + Tomasz Pawel Gajc <tpg@mandriva.org>
    - use verionate requires on java

* Wed Dec 03 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 5.0.3-5mdv2009.1
+ Revision: 309814
- add requires on libblas and liblapack
- add requires on xerces-j2

* Tue Dec 02 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 5.0.3-4mdv2009.1
+ Revision: 309497
- Patch9: fix build for latest jeuclid-core (from upstream svn)
- enable build help, since jeuclid-core is in repos
- Patch8: find jeuclid-core jar file
- fix categories in desktop file
- do not require pvm

* Tue Dec 02 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 5.0.3-3mdv2009.1
+ Revision: 309379
- rebuild for umfpack and amd libraries

* Sat Nov 22 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 5.0.3-2mdv2009.1
+ Revision: 305916
- disable build help, as it needs updated maven2
- add buildrequires on python-libxml2
- regenerate C/C++ => Java wrappers produces by giws
- enable building of help and all the docs
- add missing buildrequires on docbook-style-xsl, batik, saxon, fop
- Patch7: fix detectin of batik jar file
- regenerate Java => C wrappers produces by Swig
- use macro for configure script (thanks to Nicolas Vigier for providing a hack)
- add missing buildrequires on swig, nvurses-devel and pcre-devel
- drop not needed buildrequires
- use _disable_ld_no_undefined and _disable_ld_as_needed

* Thu Nov 20 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 5.0.3-1mdv2009.1
+ Revision: 305346
- license has changed to CeCILL, which is compiliant with GPL
- don't use macr for configure script, as it breaks compilation
- introduce devel subpackage
- fix file list
- remove hopefully useless hacks form spec file
- spec file clean
- adjust requires on java stuff
- add buildrequires on matio-devel
- disable ld no udefined(lot of missing links)
- add buildrequires on javahelp2, gluegen and jrosetta
- Patch: fix detection of jhall (javahelp2)
- Patch5: fix detecting of jgoodies-looks
- add buildrequires on jogl and umfpack-devel
- spec file clean
- add buildrequires on jgoodies-looks and flexdock
- export JAVA_HOME
- update to new version 5.0.3
- add missing buildrequires on blas-devel, lapack-devel, fftw3-devel, java-rpmbuild, ant
- disable all patches

* Wed Aug 06 2008 Paulo Andrade <pcpa@mandriva.com.br> 4.1.2-9mdv2009.0
+ Revision: 264889
- Force install directory to %%{_libdir}/%%{name}-%%{version}, for
  coherence. But the package should conflict with, possibly installed,
  32 binaries on x86_64.
- Always explicitly state tcl/tk libraries path (only "really" required
  when %%_libdir != /usr/lib) and properly specify pvm library path.
- Correct (not logged in last commit) change to also build on
  64 bit architectures.
- Fix #40910 scilab crashed when trying export graph
  Explicitly link with Xaw7, so it doesn't depend on Xprint
  Also, besides fixing #40910, add a better layout and correct some
  problems in the export list that would not display all alternatives.

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas

* Tue Apr 22 2008 Paulo Andrade <pcpa@mandriva.com.br> 4.1.2-5mdv2009.0
+ Revision: 196684
+ rebuild (emptylog)

* Tue Apr 22 2008 Paulo Andrade <pcpa@mandriva.com.br> 4.1.2-4mdv2009.0
+ Revision: 196644
+ rebuild (emptylog)

* Tue Apr 22 2008 Paulo Andrade <pcpa@mandriva.com.br> 4.1.2-3mdv2009.0
+ Revision: 196636
- Correct a problem where scilab's scipad would not work correctly
  if a configuration file did not already exist in the user's home
  directory, and a problem where scipad would try to link with files
  from devel packages, printing unnecessary warning messages.

* Thu Jan 31 2008 Paulo Andrade <pcpa@mandriva.com.br> 4.1.2-2mdv2008.1
+ Revision: 160802
- Update to compile in cooker and change to use gfortran instead of g77.

  + Thierry Vignaud <tv@mandriva.org>
    - drop old menu
    - kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Fri Oct 26 2007 Paulo Andrade <pcpa@mandriva.com.br> 4.1.2-1mdv2008.1
+ Revision: 102397
- Oops, messed in previous commit and added requires to atlas, that should have been removed.
- Update to version 4.1.2, fix Tk 8.5 dependency and add ocaml dependency.
  Minor cosmetic changes to Xaw file dialog.

* Fri Sep 28 2007 Olivier Blin <oblin@mandriva.com> 4.1.1-1mdv2008.0
+ Revision: 93801
- build on ix86 only (x86_64 build fails because configure does not
  look for tcl and tk libraries in lib64, and use g77 with invalid
  -march=athlon64 option)

  + Paulo Andrade <pcpa@mandriva.com.br>
    - Requires tcl >= 8.5. Hopefully this should fix the build problems.
    - After some "fighting" with java/ocaml support to try to add support for either
      gtk or gtk2 I give up and just add BuildRequires to xaw-devel, due to all kinds
      of errors of either duplicated or missing symbols.
    - import scilab


